
"""
Property Lists (plist) are used to serialize data on Mac OS X. Property
Lists come in two flavours: XML and binary. While the XML format is already
supported by :mod:`plistlib` module, this modules aims to implement both
formats and to expose them with an API more closely resembling that of
:mod:`json` or :mod:`pickle` modules.
"""

__author__ = 'Christoph Schindler <hop@30hopsmax.at>'
__version__ = '0.1'
__website__ = 'http://pyug.at/Projekte/BinaryPlistLib'
__license__ = 'Apache License 2.0'

__all__ = [
    'dump', 'dumps', 'load', 'loads',
    'PlistEncoder',
]

#: pass as a *format* value to use the XML on-disk format
XML_FORMAT = 0
#: pass as a *format* value to use the binary on-disk format
BINARY_FORMAT = 1

__author__ = 'Christoph Schindler <hop@30hopsmax.at>'

from .encoder import PlistEncoder

import plistlib

try:
    from cStringIO import StringIO
except ImportError:
    from StringIO import StringIO

def dump(obj, fp, format=XML_FORMAT):
    """Serialize ``obj`` as a Property List formatted stream to ``fp`` (a
    file-like object).
    """
    PlistEncoder(fp, format).dump(obj)

def dumps(obj, format=XML_FORMAT):
    """Serialize ``obj`` to ``str`` in Property List format.
    """
    fp = StringIO()
    PlistEncoder(fp, format).dump(obj)
    return fp.getvalue()

def load(fp):
    """Deserialize ``fp`` (a file-like object containing a Property List) to
    a Python object.
    """
    return plistlib.readPlist(fp)

def loads(s):
    """Deserialize ``s`` (a ``str`` or ``unicode`` instance containing a
    Property List) to a Python object.
    """
    return plistlib.readPlistFromString(s)

